@@ -87,7 +87,10 @@ class FMRadioUI(Component, Window):
         self.__rds_handler = None
         self.__current_rds_ps = ""
         self.__current_rds_rt = ""
-        self.__device = platforms.get_product_code()
+        if (platforms.MAEMO4 or platforms.MAEMO5):
+            self.__device = platforms.get_product_code()
+        else:
+            self.__device = "?"
 
         self.__sound_pipe = SoundPipe()
         self.__use_speaker = False
@@ -174,10 +177,12 @@ class FMRadioUI(Component, Window):
             
         if (self.__radio):
             self.__fmscala.set_value(config.get_lastfreq())
-            self.__display_note("The Bluetooth module is responsible for\n" \
-                                "FM radio and enabled automatically.")
+            if (platforms.MAEMO5):
+                self.__display_note("The Bluetooth module is responsible for\n" \
+                                    "FM radio and enabled automatically.")
 
         self.__update_menu()
+        self.render()
 
 
     def __display_note(self, msg):
@@ -275,6 +280,16 @@ class FMRadioUI(Component, Window):
                                  "rename": self.__on_menu_rename})
 
 
+    def __update_station_label(self):
+        """
+        Updates the station label.
+        """
+    
+        name = self.__get_current_station_name()
+        self.__lbl_station.set_text(name)
+
+
+
     def __overlay_glass(self, obj, screen):
         """
         Overlays the glass pane.
@@ -325,6 +340,16 @@ class FMRadioUI(Component, Window):
         elif (key == "Right"):
             self.__fmscala.step_up()
 
+        elif (key == "F7" and platforms.MAEMO4 and self.__radio):
+            vol, nil = self.__radio.get_volume()
+            self.__radio.set_volume(min(100, vol + 5))
+            
+        elif (key == "F8" and platforms.MAEMO4 and self.__radio):
+            vol, nil = self.__radio.get_volume()
+            self.__radio.set_volume(max(0, vol - 5))
+
+            
+
             
 
     def __on_menu_add(self):
@@ -338,11 +363,12 @@ class FMRadioUI(Component, Window):
             name = ps.strip()
 
         if (not name):
-            dlg = InputDialog("Enter Station Name")
-            dlg.add_input("Name", "%0.2f MHz" % (freq / 1000.0))
+            dlg = InputDialog("Add New Station", label_ok = "Add")
+            dlg.set_parent_window(self)
+            dlg.add_input("Name:", "%0.2f MHz" % (freq / 1000.0))
     
             ret = dlg.run()
-            if (ret == 0):                
+            if (ret == dlg.RETURN_OK):                
                 name = dlg.get_values()[0] or "%0.2f MHz" % (freq / 1000.0)
             
         if (name):
@@ -350,6 +376,7 @@ class FMRadioUI(Component, Window):
             self.__fmscala.set_stations(*self.__stations)
 
             self.__update_menu()
+            self.__update_station_label()
             self.__render_buffered()
             self.__stations_dirty = True
         
@@ -357,11 +384,13 @@ class FMRadioUI(Component, Window):
     def __on_menu_delete(self):
     
         dlg = OptionDialog("Remove Station?")
+        dlg.set_parent_window(self)
         dlg.add_option(None, "Remove")
         dlg.add_option(None, "Cancel")
         
-        ret = dlg.run()
-        if (dlg.get_choice() == 0):
+        dlg.run()
+        choice = dlg.get_choice()
+        if (choice == 0):
             freq = self.__fmscala.get_value()
             new_stations = []
             for f, n in self.__stations:
@@ -375,6 +404,7 @@ class FMRadioUI(Component, Window):
             self.__fmscala.set_stations(*self.__stations)
 
             self.__update_menu()
+            self.__update_station_label()
             self.__render_buffered()
             self.__stations_dirty = True
         #end if
@@ -382,11 +412,12 @@ class FMRadioUI(Component, Window):
         
     def __on_menu_rename(self):
 
-        dlg = InputDialog("Rename Radio Station")
-        dlg.add_input("Name", self.__get_current_station_name())
+        dlg = InputDialog("Rename Radio Station", label_ok = "Rename")
+        dlg.set_parent_window(self)
+        dlg.add_input("Name:", self.__get_current_station_name())
         
         ret = dlg.run()
-        if (ret != 0):
+        if (ret != dlg.RETURN_OK):
             return
         new_name = dlg.get_values()[0]
     
@@ -403,6 +434,7 @@ class FMRadioUI(Component, Window):
         self.__fmscala.set_stations(*self.__stations)
 
         self.__update_menu()
+        self.__update_station_label()
         self.__stations_dirty = True
         
 
@@ -466,6 +498,7 @@ class FMRadioUI(Component, Window):
         self.__stations.sort(lambda a,b:cmp(a[1].lower(), b[1].lower()))
 
         dlg = ListDialog("Stations")
+        dlg.set_parent_window(self)
         for freq, name in self.__stations:
             item = StationItem(name, freq)
             dlg.add_item(item)
@@ -475,7 +508,7 @@ class FMRadioUI(Component, Window):
         item = dlg.get_choice()
         if (item):
             freq = item.get_frequency()
-            self.__fmscala.set_value(freq)
+            gobject.idle_add(self.__fmscala.set_value, freq)
         #end if
 
 
@@ -492,7 +525,7 @@ class FMRadioUI(Component, Window):
         if (stations):
             return stations[0]
         else:
-            return ""
+            return self.__current_rds_ps
 
 
 
@@ -545,6 +578,7 @@ class FMRadioUI(Component, Window):
 
         else:
             self.__radio.set_frequency(self.__fmscala.get_value())
+            self.__radio.set_volume(50)
 
         #end if
 
@@ -646,9 +680,8 @@ class FMRadioUI(Component, Window):
         if (self.__radio):
             self.__radio.set_frequency(freq)
             
+        self.__update_station_label()
         self.__current_rds_ps = ""
-        name = self.__get_current_station_name()
-        self.__lbl_station.set_text(name)
         self.__lbl_rds.set_text("")
 
 
@@ -665,8 +698,8 @@ class FMRadioUI(Component, Window):
             rt = rdsdecode.decode(rt).encode("utf-8")
             
             if (ps):
-                self.__lbl_station.set_text(ps)
                 self.__current_rds_ps = ""
+                self.__update_station_label()
                 
             if (rt and not self.__current_rds_rt.startswith(rt)):
                 self.__lbl_rds.set_text(rt)
