@@ -21,8 +21,6 @@ class FMScala(Widget):
 
     def __init__(self):
 
-        self.__pmap_scala = None
-        
         # width of one MHz in pixels on the scala
         self.__unit_width = 1
     
@@ -35,6 +33,9 @@ class FMScala(Widget):
         # list of stations (freq, name)
         self.__stations = []
         
+        # station pixmaps: freq -> pixmap
+        self.__station_cache = {}
+        
         # current range of the scala
         self.__scala_range = (86000, 109500)
         self.__freq_range = (87500, 108000)
@@ -81,37 +82,13 @@ class FMScala(Widget):
         Prepares the scala by precomputing some values.
         """
 
-        rng1, rng2 = self.__freq_range
         r1, r2 = self.__scala_range
         ticks_w = theme.scala_ticks.get_width()
-        ticks_h = theme.scala_ticks.get_height()
         
         units = (r2 - r1) / 1000.0
         self.__unit_width = ticks_w
-        scala_w = int(ticks_w * units)
-        scala_h = 270
+        self.__total_width = int(ticks_w * units)
 
-        self.__pmap_scala = Pixmap(None, scala_w, scala_h)
-        self.__pmap_scala.fill_area(0, 0, scala_w, scala_h,
-                                    theme.color_scala_background)
-
-        x_off = int(((r1 % 1000) / 1000.0) * ticks_w)
-        freq = r1
-        for x in range(0, scala_w, ticks_w):
-            self.__pmap_scala.draw_pixbuf(theme.scala_ticks,
-                                          x, scala_h - ticks_h)
-
-            if (rng1 <= freq <= rng2):
-                self.__pmap_scala.draw_centered_text(`freq / 1000`,
-                                                     theme.font_scala_numbers,
-                                                     x - 50, 10, 100, 32,
-                                                     theme.color_scala_numbers)
-            freq += 1000
-        
-
-        #self.__scaling = w / float(_SCALE_WIDTH)
-        self.__total_width = scala_w #int((r2 - r1) * self.__scaling)
-        
         
     def set_size(self, w, h):
     
@@ -158,68 +135,81 @@ class FMScala(Widget):
 
         #x, y = self.get_screen_pos()
         w, h = self.get_size()
+        ticks_w = theme.scala_ticks.get_width()
+        ticks_h = theme.scala_ticks.get_height()
+        rng1, rng2 = self.__freq_range
+
         #screen = self.get_screen()    
 
-        self.__buffer.copy_buffer(self.__pmap_scala,
-                                  self.__offset + x1, 0,
-                                  x1, 0,
-                                  x2 - x1, h)
-                                  
-                                   
-        """
-        r1, r2 = self.__range
-
-        self.__buffer.fill_area(x1, 0, x2 - x1, h, theme.color_fmradio_scala_bg)
         self.__buffer.set_clip_rect(x1, 0, x2 - x1, h)
-        for xpos in range(x1 - 50, x2 + 50):
-            freq = r1 + int((self.__offset - w / 2 + xpos) / self.__scaling)
-            freq -= (freq % 10)
+        self.__buffer.fill_area(x1, 0, x2 - x1, h, theme.color_scala_background)
 
-            # don't render outside of the current frequency band
-            if (freq < r1 or freq > r2): continue
+        offset = (self.__offset + x1) % ticks_w
+        remainder = ticks_w - offset
+        
+        # render ticks
+        for x in range(x1 - offset, x2, ticks_w):
+            self.__buffer.draw_pixbuf(theme.scala_ticks, x, h - ticks_h)
+        #end if
 
-            h6 = h / 6
+        # render stations
+        for freq, name in self.__stations:
+            x = self.__freq_to_px(freq)
+            if (self.__offset + x1 - offset <= x <= self.__offset + x2 + 50):
+            #if (self.__offset + x1 <= x <= self.__offset + x2 - 27):
+                pmap = self.__station_cache.get(freq)
+                if (not pmap):
+                    pmap = self.__make_station_pmap(x - self.__offset - 13, 0,
+                                                    name)
+                    if (self.__offset + x1 + 13 <= x <= self.__offset + x2 - 27):
+                        self.__station_cache[freq] = pmap
+                #else:
+                #    print "FROM CACHE", name
 
-            # render ticks only when on visible screen
-            if (x1 - 1 <= xpos < x2 + 1):
-                # determine type of tick to render
-                if (freq % 1000 == 0):
-                    self.__buffer.fill_area(xpos - 1, h6,
-                                            2, 5 * h6,
-                                            theme.color_fmradio_scala_ticks1)
+                self.__buffer.copy_buffer(pmap,
+                                          0, 0,
+                                          x - self.__offset - 13, 0,
+                                          27, 270)
                 
-                elif (freq % 500 == 0):
-                    self.__buffer.fill_area(xpos - 1, 3 * h6,
-                                            2, 3 * h6,
-                                            theme.color_fmradio_scala_ticks1)
-
-                elif (freq % 100 == 0):
-                    self.__buffer.fill_area(xpos - 1, 5 * h6,
-                                            2, 1 * h6,
-                                            theme.color_fmradio_scala_ticks2)
-
+            
+                """
+                pmap = self.__buffer.subpixmap(x - self.__offset - 13, 0,
+                                               27, 270)
+                pmap.rotate(270)
+                pmap.draw_pixbuf(theme.scala_rdslabel, 0, 0)
+                pmap.draw_text(name, theme.font_scala_station,
+                               24, 0, theme.color_scala_station)
+            
+                pmap.rotate(90)
+                self.__buffer.copy_buffer(pmap,
+                                          0, 0,
+                                          x - self.__offset - 13, 0,
+                                          27, 270)
+                del pmap
+                """
             #end if
+        #end for
+        
+        self.__buffer.set_clip_rect(None)
 
-
-            # labels should be rendered outside the visible area as well to
-            # avoid cutoffs
-            if (freq % 1000 == 0):
+        # render frequency labels
+        for x in range(x1 - offset, x2 + 100, ticks_w):
+            freq = self.__px_to_freq(self.__offset + x)
+            if (rng1 <= freq <= rng2):
+                self.__buffer.fill_area(x - 50, 10, 100, 32,
+                                        theme.color_scala_background)
                 self.__buffer.draw_centered_text(`freq / 1000`,
                                                  theme.font_scala_numbers,
-                                                 xpos - 50, 0, 100, 32,
+                                                 x - 50, 10, 100, 32,
                                                  theme.color_scala_numbers)
-
-            # render station label
-            if (freq % 100 == 0):
-                pmap = self.__stations.get(freq)
-                if (pmap):
-                    p_w, p_h = pmap.get_size()
-                    self.__buffer.draw_pixmap(pmap,
-                                              xpos - p_w / 2, h - h6 - p_h)
-                
         #end for
-        self.__buffer.set_clip_rect(None)
-        """
+            
+
+        #self.__buffer.copy_buffer(self.__pmap_scala,
+        #                          self.__offset + x1, 0,
+        #                          x1, 0,
+        #                          x2 - x1, h)
+
                 
         
     def set_range(self, a, b):
@@ -237,8 +227,25 @@ class FMScala(Widget):
         b -= b % 1000
         self.__scala_range = (a, b)
         
-        self.__prepare_scala()
-        self.__prepare_stations()
+        ticks_w = theme.scala_ticks.get_width()
+        units = (b - a) / 1000.0
+        self.__unit_width = ticks_w
+        self.__total_width = int(ticks_w * units)
+
+
+    def __make_station_pmap(self, x, y, name):
+        """
+        Creates and returns a station label pixmap.
+        """
+
+        pmap = self.__buffer.subpixmap(x, y, 27, 270)
+        pmap.rotate(270)
+        pmap.draw_pixbuf(theme.scala_rdslabel, 0, 0)
+        pmap.draw_text(name, theme.font_scala_station,
+                       24, 0, theme.color_scala_station)
+        pmap.rotate(90)
+
+        return pmap
 
 
     def set_stations(self, *stations):
@@ -249,30 +256,10 @@ class FMScala(Widget):
         """
     
         self.__stations = stations
-        self.__prepare_scala()
-        self.__prepare_stations()
+        self.__station_cache.clear()
         self.__buffer_invalidated = True
         
         
-    def __prepare_stations(self):
-        
-        for freq, name in self.__stations:
-            if (not name.strip()):
-                name = "unnamed"
-            
-            xpos = self.__freq_to_px(freq)
-            pmap = self.__pmap_scala.subpixmap(xpos - 13, 0, 27, 270)
-            pmap.rotate(270)
-            pmap.draw_pixbuf(theme.scala_rdslabel, 0, 0)
-            pmap.draw_text(name, theme.font_scala_station,
-                           24, 0, theme.color_scala_station)
-            
-            pmap.rotate(90)
-            self.__pmap_scala.copy_buffer(pmap, 0, 0, xpos - 13, 0, 27, 270)
-            del pmap
-        #end for
-
-
     def __freq_to_px(self, freq):
     
         r1, r2 = self.__scala_range
