@@ -23,24 +23,24 @@ class StationItem(Item):
         
         pmap, is_new = self._get_cached_pixmap()
         if (is_new):
-            pmap.fill_area(0, 0, w, h, theme.color_mb_background)
+            pmap.fill_area(0, 0, w, h, theme.color_ui_background)
 
             # render selection frame
             if (self.is_hilighted() or self.is_marked()):
-                pmap.draw_frame(theme.mb_selection_frame, 0, 0, w, h, True,
+                pmap.draw_frame(theme.ui_selection_frame, 0, 0, w, h, True,
                                 pmap.TOP | pmap.BOTTOM | pmap.LEFT | pmap.RIGHT)
            
             offset = 20
             
             # render text
             pmap.set_clip_rect(0, 0, w - 80, h)
-            pmap.draw_text(self.__name, theme.font_mb_listitem_text,
+            pmap.draw_text(self.__name, theme.font_ui_listitem_text,
                            offset, 10,
-                           theme.color_mb_listitem_text)
+                           theme.color_ui_listitem_text)
             pmap.draw_text("%0.2f MHz" % (self.__frequency / 1000.0),
-                           theme.font_mb_listitem_subtext,
+                           theme.font_ui_listitem_subtext,
                            offset, h - 36,
-                           theme.color_mb_listitem_subtext)
+                           theme.color_ui_listitem_subtext)
             pmap.set_clip_rect()
             
         #end if
