@@ -3,8 +3,13 @@ import platforms
 
 def get_classes():
 
-    from HeadphonesMonitor import HeadphonesMonitor
-    classes = [HeadphonesMonitor]
+    classes = []
+    
+    if (platforms.MAEMO4 or platforms.MAEMO5):
+        from HeadphonesMonitor import HeadphonesMonitor
+        from DBusMonitor import DBusMonitor
+        classes += [HeadphonesMonitor,
+                    DBusMonitor]
 
     if (platforms.MAEMO5):
         from SoundVolumeMonitor import SoundVolumeMonitor
@@ -13,7 +18,7 @@ def get_classes():
         classes += [SoundVolumeMonitor,
                     PhoneMonitor,
                     PolicyMonitor]
-        
+
     return classes
 
 
