@@ -20,7 +20,7 @@ class ListDialog(Window):
         self.__list = ThumbableGridView()
         self.add(self.__list)
         
-        self.__slider = VSlider(theme.mb_list_slider)
+        self.__slider = VSlider(theme.ui_list_slider)
         self.add(self.__slider)
         self.__list.associate_with_slider(self.__slider)
 
@@ -55,3 +55,11 @@ class ListDialog(Window):
     
         return self.__choice
 
+
+    def set_visible(self,v ):
+
+        if (v):
+            w = gtk.gdk.screen_width()
+            h = gtk.gdk.screen_height() - 120
+            self.set_window_size(w, h)
+        Window.set_visible(self, v)
