@@ -21,7 +21,7 @@ class CheckBoxItem(Item):
     
         pmap, is_new = self._get_cached_pixmap()
         if (is_new):
-            pmap.fill_area(0, 0, w, h, theme.color_mb_background)
+            pmap.fill_area(0, 0, w, h, theme.color_ui_background)
 
             if (self.__is_checked):
                 pbuf = theme.mb_checkbox_2
@@ -31,9 +31,10 @@ class CheckBoxItem(Item):
             pmap.draw_pixbuf(pbuf, 4, 4)
 
             pmap.set_clip_rect(5, 5, w - 10, h - 10)
-            pmap.draw_text(self.__label, theme.font_mb_tiny,
-                           pbuf.get_width() + 10, 10,
-                           theme.color_mb_listitem_text)
+            offset = pbuf.get_width() + 10
+            pmap.draw_formatted_text(self.__label, theme.font_ui_plain,
+                                     offset, 8, w - offset - 10, h - 8,
+                                     theme.color_ui_listitem_text)
             pmap.set_clip_rect()
         #end if
         
