@@ -3,7 +3,7 @@ from ui.Pixmap import Pixmap
 
 
 # maximum cache size
-_CACHE_SIZE = 20
+_CACHE_SIZE = 50
 
 # list of tuples (item, pixmap)
 _CACHE = []
@@ -23,6 +23,7 @@ class Item(EventEmitter):
         self.__size = (240, 80)
         self.__is_hilighted = False
         self.__is_marked = False
+        self.__is_draggable = False
 
         EventEmitter.__init__(self)
 
@@ -70,6 +71,16 @@ class Item(EventEmitter):
         return self.__is_marked
 
 
+    def set_draggable(self, v):
+    
+        self.__is_draggable = v
+        
+        
+    def is_draggable(self):
+    
+        return self.__is_draggable
+
+
     def render_at(self, cnv, x, y):
 
         w, h = self.get_size()
