@@ -1,10 +1,11 @@
 from GtkWindow import Window as GtkWindow
 from ui.Pixmap import Pixmap
+from ui import windowflags
 from utils.MiniXML import MiniXML
 from theme import theme
+import platforms
 
-import gtk
-import hildon
+from wrapper import gtk, hildon
 
 
 class Window(GtkWindow):
@@ -24,8 +25,8 @@ class Window(GtkWindow):
             
         elif (wtype == self.TYPE_DIALOG):
             self.__window = gtk.Dialog()
-            self.__window.resize(gtk.gdk.screen_width(),
-                                 gtk.gdk.screen_height() - 120)
+            self.__window.connect("button-press-event",
+                                  self.__check_close_dialog)
                 
         self.__window.set_title("Loading")
         self._set_gtk_window(self.__window)
@@ -48,7 +49,14 @@ class Window(GtkWindow):
                                              [1])
         """
 
-    """
+
+    def __check_close_dialog(self, src, ev):
+    
+        px, py = src.get_pointer()
+        if (py < 0):
+            self.emit_event(self.EVENT_CLOSED)
+
+
     def set_visible(self, v):
     
         #if (v and self.__wtype == self.TYPE_DIALOG):
@@ -56,12 +64,7 @@ class Window(GtkWindow):
         #                         gtk.gdk.screen_height() - 120)
 
         GtkWindow.set_visible(self, v)
-    """
-    
 
-    def set_size(self, w, h):
-        
-        self.__window.resize(w, h)
 
 
     def __set_portrait_property(self, prop, value):
@@ -71,32 +74,40 @@ class Window(GtkWindow):
                                              [value])
 
 
-    def set_fullscreen_mode(self, v):
+    def set_flags(self, flags):
     
-        if (v):
+        if (flags & windowflags.FULLSCREEN):
             self.__window.fullscreen()
         else:
             self.__window.unfullscreen()
 
-
-    def set_portrait_mode(self, v):
-        
-        if (v):
+        if (flags & windowflags.PORTRAIT):
             self.__set_portrait_property("_HILDON_PORTRAIT_MODE_SUPPORT", 1)
             self.__set_portrait_property("_HILDON_PORTRAIT_MODE_REQUEST", 1)
         else:
             self.__set_portrait_property("_HILDON_PORTRAIT_MODE_SUPPORT", 1)
             self.__set_portrait_property("_HILDON_PORTRAIT_MODE_REQUEST", 0)
 
+        if (flags & windowflags.BUSY):
+            hildon.hildon_gtk_window_set_progress_indicator(self.__window, 1)
+        else:
+            hildon.hildon_gtk_window_set_progress_indicator(self.__window, 0)
 
-    def set_busy(self, value):
-        
-        hildon.hildon_gtk_window_set_progress_indicator(self.__window,
-                                                        value and 1 or 0) 
+        self.emit_event(self.EVENT_SCREEN_CHANGED)
+
+
+    def show_menu(self):
+    
+        self.__window.show_app_menu()
 
 
     def set_menu_xml(self, xml, bindings):
     
+        def menu_cb(cb, *args):
+            if (platforms.MAEMO4):
+                self.__window.hide_app_menu()
+            cb(*args)
+    
         dom = MiniXML(xml).get_dom()        
         menu = hildon.AppMenu()
         
@@ -111,7 +122,8 @@ class Window(GtkWindow):
                 btn.set_label(item_label)
                 if (callback):
                     btn.connect("clicked",
-                                lambda x, cb:cb(), callback)
+                                lambda x, cb:menu_cb(cb), callback)
+                                #lambda x, cb:cb(), callback)
                 menu.append(btn)
 
             elif (name == "choice"):
@@ -130,7 +142,8 @@ class Window(GtkWindow):
                     
                     if (callback):
                         btn.connect("clicked",
-                                    lambda x, i, cb:cb(i), cnt, callback)
+                                    lambda x, i, cb:menu_cb(cb, i), cnt, callback)
+                                    #lambda x, i, cb:cb(i), cnt, callback)
                     if (item_label):
                         btn.set_label(item_label)
                     if (item_icon):
